from .branding import print_banner
def main():
    print_banner()
    print("\nTry:\n  tokra-shield hello\n  tokra-shield check \"free crypto\" --lang en\n  tokra-shield run")
if __name__ == "__main__":
    main()
